- The `shuffle` and the `random_state` parameters are deprecated on
  :class:`~preprocessing.TargetEncoder` and will be removed in version 1.11. Pass a
  cross-validation generator as `cv` argument to specify the shuffling behaviour
  instead.
  By :user:`Stefanie Senger <StefanieSenger>`.
